==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/nb-NO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tilbehør sjekket inn',
    'Accessory_Checkout_Notification' => 'Tilbehør sjekket ut',
    'Asset_Checkin_Notification' => 'Eiendel sjekket inn',
    'Asset_Checkout_Notification' => 'Ressurs sjekket ut',
    'Confirm_Accessory_Checkin' => 'Bekreft innsjekk av tilbehør',
    'Confirm_Asset_Checkin' => 'Bekreft innsjekk av eiendel',
    'Confirm_accessory_delivery' => 'Bekreft levering av tilbehør',
    'Confirm_asset_delivery' => 'Bekreft levering av eiendel',
    'Confirm_consumable_delivery' => 'Bekreft levering av forbruksvare',
    'Confirm_license_delivery' => 'Bekreft levering av lisens',
    'Consumable_checkout_notification' => 'Forbruksvaren tatt ut',
    'Days' => 'Dager',
    'Expected_Checkin_Date' => 'En enhet som er sjekket ut til deg skal leveres tilbake den :date',
    'Expected_Checkin_Notification' => 'Påminnelse: Innsjekkingsfrist for :name nærmer seg',
    'Expected_Checkin_Report' => 'Rapport over forventet innsjekking av eiendeler',
    'Expiring_Assets_Report' => 'Rapport utløpende eiendeler.',
    'Expiring_Licenses_Report' => 'Rapport utløpende lisenser.',
    'Item_Request_Canceled' => 'Forespørsel av enhet avbrutt',
    'Item_Requested' => 'Forespurt enhet',
    'License_Checkin_Notification' => 'Lisens sjekket inn',
    'License_Checkout_Notification' => 'Lisens sjekket ut',
    'Low_Inventory_Report' => 'Rapport lav lagerbeholdning',
    'a_user_canceled' => 'Brukeren har avbrutt en element-forespørsel på webområdet',
    'a_user_requested' => 'En bruker har bedt om et element på webområdet',
    'acceptance_asset_accepted' => 'En bruker har godtatt et element',
    'acceptance_asset_declined' => 'En bruker har avvist et element',
    'accessory_name' => 'Navn tilbehør:',
    'additional_notes' => 'Flere notater:',
    'admin_has_created' => 'En administrator har opprettet en konto for deg på :web nettsted.',
    'asset' => 'Eiendel:',
    'asset_name' => 'Navn:',
    'asset_requested' => 'Eiendel forespurt',
    'asset_tag' => 'Eiendelsmerke',
    'assets_warrantee_alert' => 'En eiendel har garanti som utløper innenfor de neste :treshold dagene.|:count eiendeler har garanti som utløper innenfor de neste :tershold dagene.',
    'assigned_to' => 'Tilordnet til',
    'best_regards' => 'Med vennlig hilsen,',
    'canceled' => 'Avbrutt:',
    'checkin_date' => 'Innsjekkdato:',
    'checkout_date' => 'Utsjekkdato:',
    'checkedout_from' => 'Sjekket ut fra',
    'checkedin_from'  => 'Sjekket inn fra',
    'checked_into' => 'Sjekket inn',
    'click_on_the_link_accessory' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt tilbehøret.',
    'click_on_the_link_asset' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt eiendelen.',
    'click_to_confirm' => 'Klikk på følgende link for å bekrefte din :web konto:',
    'current_QTY' => 'Nåværende antall',
    'days' => 'Dager',
    'expecting_checkin_date' => 'Forventet innsjekkdato:',
    'expires' => 'Utløper',
    'hello' => 'Hallo',
    'hi' => 'Hei',
    'i_have_read' => 'Jeg har lest og godtar vilkårene for bruk, og har mottatt denne enheten.',
    'inventory_report' => 'Lagerbeholdnings rapport',
    'item' => 'Enhet:',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':count lisens utløper de neste :threshold dagene.|:count lisenser utløper de neste :threshold dagene.',
    'link_to_update_password' => 'Klikk på følgende link for å bekrefte din :web passord:',
    'login' => 'Logg inn:',
    'login_first_admin' => 'Logg inn på din nye Snipe-IT-installasjon ved å bruke kontoen nedenfor:',
    'low_inventory_alert' => ':count enhet er under minimumnivå for beholdning, eller vil snart nå dette nivået.|:count enheter er under minimumnivå for beholdning, eller vil snart nå dette nivået.',
    'min_QTY' => 'Min. antall',
    'name' => 'Navn',
    'new_item_checked' => 'En ny enhet har blitt sjekket ut under ditt navn, detaljer nedenfor.',
    'notes' => 'Notater',
    'password' => 'Passord:',
    'password_reset' => 'Tilbakestill passord',
    'read_the_terms' => 'Vennligst les bruksbetingelsene nedenfor.',
    'read_the_terms_and_click' => 'Vennligst les vilkårene for bruk nedenfor. og klikk på lenken nederst for å bekrefte at du leser og godtar vilkårene for bruk, og har mottatt eiendelen.',
    'requested' => 'Forespurt:',
    'reset_link' => 'Lenke for tilbakestilling av passord',
    'reset_password' => 'Klikk her for å tilbakestille passordet:',
    'rights_reserved' => 'Alle rettigheter forbeholdt.',
    'serial' => 'Serienummer',
    'snipe_webhook_test' => 'Snipe-IT integrasjonstest',
    'snipe_webhook_summary' => 'Snipe-IT integrasjon test sammendrag',
    'supplier' => 'Leverandør',
    'tag' => 'Merke',
    'test_email' => 'Test-epost fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT eiendelsadministrasjonssystem. Hvis du mottok denne meldingen fungerer e-post.',
    'the_following_item' => 'Følgende enheter har blitt sjekket inn: ',
    'to_reset' => 'Fullfør dette skjemaet for å tilbakestille ditt :web passord:',
    'type' => 'Type',
    'upcoming-audits' => ':count eiendel har revisjonsfrist innen :treshold dager.|:count eiendeler har revisjonsfrist innen :threshold dager.',
    'user' => 'Bruker',
    'username' => 'Brukernavn',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Velkommen :name',
    'welcome_to' => 'Velkommen til :web!',
    'your_assets' => 'Vis dine eiendeler',
    'your_credentials' => 'Din Snipe-IT konto',
    'mail_sent' => 'Mail sent successfully!',
];

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/nb-NO/mail.php <==
<?php

return [

    'Accessory_Checkin_Notification' => 'Tilbehør sjekket inn',
    'Accessory_Checkout_Notification' => 'Tilbehør sjekket ut',
    'Asset_Checkin_Notification' => 'Eiendel sjekket inn',
    'Asset_Checkout_Notification' => 'Ressurs sjekket ut',
    'Confirm_Accessory_Checkin' => 'Bekreft innsjekk av tilbehør',
    'Confirm_Asset_Checkin' => 'Bekreft innsjekk av eiendel',
    'Confirm_accessory_delivery' => 'Bekreft levering av tilbehør',
    'Confirm_asset_delivery' => 'Bekreft levering av eiendel',
    'Confirm_consumable_delivery' => 'Bekreft levering av forbruksvare',
    'Confirm_license_delivery' => 'Bekreft levering av lisens',
    'Consumable_checkout_notification' => 'Forbruksvaren tatt ut',
    'Days' => 'Dager',
    'Expected_Checkin_Date' => 'En enhet som er sjekket ut til deg skal leveres tilbake den :date',
    'Expected_Checkin_Notification' => 'Påminnelse: Innsjekkingsfrist for :name nærmer seg',
    'Expected_Checkin_Report' => 'Rapport over forventet innsjekking av eiendeler',
    'Expiring_Assets_Report' => 'Rapport utløpende eiendeler.',
    'Expiring_Licenses_Report' => 'Rapport utløpende lisenser.',
    'Item_Request_Canceled' => 'Forespørsel av enhet avbrutt',
    'Item_Requested' => 'Forespurt enhet',
    'License_Checkin_Notification' => 'Lisens sjekket inn',
    'License_Checkout_Notification' => 'Lisens sjekket ut',
    'license_for'   => 'License for',
    'Low_Inventory_Report' => 'Rapport lav lagerbeholdning',
    'a_user_canceled' => 'Brukeren har avbrutt en element-forespørsel på webområdet',
    'a_user_requested' => 'En bruker har bedt om et element på webområdet',
    'acceptance_asset_accepted' => 'En bruker har godtatt et element',
    'acceptance_asset_declined' => 'En bruker har avvist et element',
    'accessory_name' => 'Navn tilbehør',
    'additional_notes' => 'Flere notater',
    'admin_has_created' => 'En administrator har opprettet en konto for deg på :web nettsted.',
    'asset' => 'Eiendel',
    'asset_name' => 'Navn',
    'asset_requested' => 'Eiendel forespurt',
    'asset_tag' => 'Eiendelsmerke',
    'assets_warrantee_alert' => 'En eiendel har garanti som utløper innenfor de neste :treshold dagene.|:count eiendeler har garanti som utløper innenfor de neste :tershold dagene.',
    'assigned_to' => 'Tilordnet til',
    'best_regards' => 'Med vennlig hilsen,',
    'canceled' => 'Avbrutt',
    'checkin_date' => 'Innsjekkdato',
    'checkout_date' => 'Utsjekkdato',
    'checkedout_from' => 'Sjekket ut fra',
    'checkedin_from'  => 'Sjekket inn fra',
    'checked_into' => 'Sjekket inn',
    'click_on_the_link_accessory' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt tilbehøret.',
    'click_on_the_link_asset' => 'Vennligst klikk på lenken nedenfor for å bekreft at du har mottatt eiendelen.',
    'click_to_confirm' => 'Klikk på følgende link for å bekrefte din :web konto:',
    'current_QTY' => 'Nåværende antall',
    'days' => 'Dager',
    'expecting_checkin_date' => 'Forventet dato for innsjekk',
    'expires' => 'Utløper',
    'hello' => 'Hallo',
    'hi' => 'Hei',
    'i_have_read' => 'Jeg har lest og godtar vilkårene for bruk, og har mottatt denne enheten.',
    'inventory_report' => 'Lagerbeholdnings rapport',
    'item' => 'Enhet',
    'item_checked_reminder' => 'This is a reminder that you currently have :count items checked out to you that you have not accepted or declined. Please click the link below to confirm your decision.',
    'license_expiring_alert' => ':count lisens utløper de neste :threshold dagene.|:count lisenser utløper de neste :threshold dagene.',
    'link_to_update_password' => 'Klikk på følgende link for å bekrefte din :web passord:',
    'login' => 'Logg inn',
    'login_first_admin' => 'Logg inn på din nye Snipe-IT-installasjon ved å bruke kontoen nedenfor:',
    'low_inventory_alert' => ':count enhet er under minimumnivå for beholdning, eller vil snart nå dette nivået.|:count enheter er under minimumnivå for beholdning, eller vil snart nå dette nivået.',
    'min_QTY' => 'Min. antall',
    'name' => 'Navn',
    'new_item_checked' => 'En ny enhet har blitt sjekket ut under ditt navn, detaljer nedenfor.',
    'notes' => 'Notater',
    'password' => 'Passord',
    'password_reset' => 'Tilbakestill passord',
    'read_the_terms' => 'Vennligst les bruksbetingelsene nedenfor.',
    'read_the_terms_and_click' => 'Vennligst les vilkårene for bruk nedenfor. og klikk på lenken nederst for å bekrefte at du leser og godtar vilkårene for bruk, og har mottatt eiendelen.',
    'requested' => 'Forespurt',
    'reset_link' => 'Lenke for tilbakestilling av passord',
    'reset_password' => 'Klikk her for å tilbakestille passordet:',
    'rights_reserved' => 'Alle rettigheter forbeholdt.',
    'serial' => 'Serienummer',
    'snipe_webhook_test' => 'Snipe-IT integrasjonstest',
    'snipe_webhook_summary' => 'Snipe-IT integrasjon test sammendrag',
    'supplier' => 'Leverandør',
    'tag' => 'Merke',
    'test_email' => 'Test-epost fra Snipe-IT',
    'test_mail_text' => 'Dette er en test fra Snipe-IT eiendelsadministrasjonssystem. Hvis du mottok denne meldingen fungerer e-post.',
    'the_following_item' => 'Følgende enheter har blitt sjekket inn: ',
    'to_reset' => 'Fullfør dette skjemaet for å tilbakestille ditt :web passord:',
    'type' => 'Type',
    'upcoming-audits' => ':count eiendel har revisjonsfrist innen :treshold dager.|:count eiendeler har revisjonsfrist innen :threshold dager.',
    'user' => 'Bruker',
    'username' => 'Brukernavn',
    'unaccepted_asset_reminder' => 'You have Unaccepted Assets.',
    'welcome' => 'Velkommen :name',
    'welcome_to' => 'Velkommen til :web!',
    'your_assets' => 'Vis dine eiendeler',
    'your_credentials' => 'Din Snipe-IT konto',
    'mail_sent' => 'Mail sent successfully!',
];
